@@ -1151,11 +1151,23 @@ add_theme_button_clicked(GtkWidget *btn, const char *theme_type)
 static GtkWidget *
 make_add_theme_button(const char *theme_type)
 {
-	GtkWidget *btn = g_object_new(HILDON_TYPE_BUTTON,
+	GtkWidget *btn = g_object_new(
+#if HILDON_CHECK_VERSION(2,1,0)
+		HILDON_TYPE_BUTTON,
+#else /* HILDON < 2.1.0 */
+		GTK_TYPE_BUTTON,
+#endif /* HILDON >= 2.1.0 */
 		"visible",     TRUE,
-		"title",       _("Add"),
+#if HILDON_CHECK_VERSION(2,1,0)
+		"title",
+#else /* HILDON < 2.1.0 */
+		"label",
+#endif /* HILDON >= 2.1.0 */
+		               _("Add"),
+#if HILDON_CHECK_VERSION(2,1,0)
 		"size",        HILDON_SIZE_FINGER_HEIGHT,
 		"arrangement", HILDON_BUTTON_ARRANGEMENT_VERTICAL,
+#endif /* HILDON >= 2.1.0 */
 		NULL);
 
 	g_signal_connect(G_OBJECT(btn), "clicked", (GCallback)add_theme_button_clicked, (gpointer)theme_type);
@@ -1165,9 +1177,12 @@ make_add_theme_button(const char *theme_type)
 #endif /* USE_HILDON */
 
 static GtkWidget *
-add_theme_prefs_combo(GtkWidget *vbox, GtkSizeGroup *combo_sg, GtkSizeGroup *label_sg, GtkListStore *theme_store,
+add_theme_prefs_combo(GtkWidget *vbox,
+                      GtkSizeGroup *combo_sg, GtkSizeGroup *label_sg,
+                      GtkListStore *theme_store,
                       GCallback combo_box_cb, gpointer combo_box_cb_user_data, 
-                      const char *label_str, const char *prefs_path, const char *theme_type)
+                      const char *label_str, const char *prefs_path,
+                      const char *theme_type)
 {
 	GtkWidget *label;
 	GtkWidget *combo_box = NULL;
@@ -1185,7 +1200,7 @@ add_theme_prefs_combo(GtkWidget *vbox, GtkSizeGroup *combo_sg, GtkSizeGroup *lab
 	gtk_box_pack_start(GTK_BOX(themesel_hbox), label, FALSE, FALSE, 0);
 
 	combo_box = prefs_build_theme_combo_box(theme_store,
-						purple_prefs_get_string(full_prefs_path),
+						purple_prefs_get_string(prefs_path),
 						theme_type);
 	g_signal_connect(G_OBJECT(combo_box), "changed",
 						(GCallback)combo_box_cb, combo_box_cb_user_data);
@@ -1237,25 +1252,25 @@ theme_page(void)
 	prefs_blist_themes_combo_box = add_theme_prefs_combo(
 		vbox, combo_sg, label_sg, prefs_blist_themes,
 		(GCallback)prefs_set_blist_theme_cb, NULL, 
-		_("Buddy List Theme:"), "/blist/theme", "blist");
+		_("Buddy List Theme:"), PIDGIN_PREFS_ROOT "/blist/theme", "blist");
 
 	/* Status Icon Themes */
 	prefs_status_themes_combo_box = add_theme_prefs_combo(
 		vbox, combo_sg, label_sg, prefs_status_icon_themes,
 		(GCallback)prefs_set_status_icon_theme_cb, NULL,
-		_("Status Icon Theme:"), "/status/icon-theme", "icon");
+		_("Status Icon Theme:"), PIDGIN_PREFS_ROOT "/status/icon-theme", "icon");
 
 	/* Sound Themes */
 	prefs_sound_themes_combo_box = add_theme_prefs_combo(
 		vbox, combo_sg, label_sg, prefs_sound_themes,
 		(GCallback)prefs_set_sound_theme_cb, NULL,
-		_("Sound Theme:"), "/sound/theme", "sound");
+		_("Sound Theme:"), PIDGIN_PREFS_ROOT "/sound/theme", "sound");
 
 	/* Smiley Themes */
 	prefs_smiley_themes_combo_box = add_theme_prefs_combo(
 		vbox, combo_sg, label_sg, prefs_smiley_themes,
 		(GCallback)prefs_set_smiley_theme_cb, NULL,
-		_("Smiley Theme:"), "/smileys/theme", "smiley");
+		_("Smiley Theme:"), PIDGIN_PREFS_ROOT "/smileys/theme", "smiley");
 
 	/* Custom sort so "none" theme is at top of list */
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(prefs_smiley_themes),
@@ -1930,9 +1945,10 @@ network_page(void)
 
 	hbox = pidgin_add_widget_to_vbox(GTK_BOX(vbox), _("_TURN server:"),
 			sg, entry, TRUE, NULL);
-
-	pidgin_prefs_labeled_spin_button(hbox, _("_Port:"),
+	
+	pidgin_prefs_labeled_spin_button(hbox, _("_UDP Port:"),
 		"/purple/network/turn_port", 0, 65535, NULL);
+
 	hbox = pidgin_prefs_labeled_entry(vbox, _("Use_rname:"),
 		"/purple/network/turn_username", sg);
 	pidgin_prefs_labeled_password(hbox, _("Pass_word:"),
@@ -1950,7 +1966,7 @@ manual_browser_set(GtkWidget *entry, GdkEventFocus *event, gpointer data)
 {
 	const char *program = gtk_entry_get_text(GTK_ENTRY(entry));
 
-	purple_prefs_set_path(PIDGIN_PREFS_ROOT "/browsers/command", program);
+	purple_prefs_set_string(PIDGIN_PREFS_ROOT "/browsers/manual_command", program);
 
 	/* carry on normally */
 	return FALSE;
@@ -1971,12 +1987,19 @@ get_available_browsers(void)
 		{N_("Netscape"), "netscape"},
 		{N_("Mozilla"), "mozilla"},
 		{N_("Konqueror"), "kfmclient"},
+		{N_("Google Chrome"), "google-chrome"},
+		/* Do not move the line below.  Code below expects gnome-open to be in
+		 * this list immediately after xdg-open! */
 		{N_("Desktop Default"), "xdg-open"},
 		{N_("GNOME Default"), "gnome-open"},
 		{N_("Galeon"), "galeon"},
 		{N_("Firefox"), "firefox"},
 		{N_("Firebird"), "mozilla-firebird"},
-		{N_("Epiphany"), "epiphany"}
+		{N_("Epiphany"), "epiphany"},
+		/* Translators: please do not translate "chromium-browser" here! */
+		{N_("Chromium (chromium-browser)"), "chromium-browser"},
+		/* Translators: please do not translate "chrome" here! */
+		{N_("Chromium (chrome)"), "chrome"}
 	};
 	static const int num_possible_browsers = G_N_ELEMENTS(possible_browsers);
 
@@ -2107,7 +2130,7 @@ browser_page(void)
 
 		entry = gtk_entry_new();
 		gtk_entry_set_text(GTK_ENTRY(entry),
-						   purple_prefs_get_path(PIDGIN_PREFS_ROOT "/browsers/command"));
+						   purple_prefs_get_string(PIDGIN_PREFS_ROOT "/browsers/manual_command"));
 		g_signal_connect(G_OBJECT(entry), "focus-out-event",
 						 G_CALLBACK(manual_browser_set), NULL);
 		hbox = pidgin_add_widget_to_vbox(GTK_BOX(vbox), _("_Manual:\n(%s for URL)"), sg, entry, TRUE, NULL);
@@ -2987,8 +3010,8 @@ pidgin_prefs_init(void)
 	/* Browsers */
 	purple_prefs_add_none(PIDGIN_PREFS_ROOT "/browsers");
 	purple_prefs_add_int(PIDGIN_PREFS_ROOT "/browsers/place", PIDGIN_BROWSER_DEFAULT);
-	purple_prefs_add_path(PIDGIN_PREFS_ROOT "/browsers/command", "");
-	purple_prefs_add_string(PIDGIN_PREFS_ROOT "/browsers/browser", "mozilla");
+	purple_prefs_add_string(PIDGIN_PREFS_ROOT "/browsers/manual_command", "");
+	purple_prefs_add_string(PIDGIN_PREFS_ROOT "/browsers/browser", "xdg-open");
 #endif
 
 	/* Plugins */
@@ -3018,7 +3041,7 @@ pidgin_prefs_init(void)
 void
 pidgin_prefs_update_old(void)
 {
-	const char *str;
+	const char *str = NULL;
 
 	purple_prefs_rename("/gaim/gtk", PIDGIN_PREFS_ROOT);
 
@@ -3034,6 +3057,17 @@ pidgin_prefs_update_old(void)
 	purple_prefs_rename_boolean_toggle(PIDGIN_PREFS_ROOT "/conversations/ignore_colors",
 									 PIDGIN_PREFS_ROOT "/conversations/show_incoming_formatting");
 
+	/*
+	 * this path pref changed to a string, so migrate.  I know this will break
+	 * things for and confuse users that use multiple versions with the same
+	 * config directory, but I'm not inclined to want to deal with that at the
+	 * moment. -- rekkanoryo
+	 */
+	if((str = purple_prefs_get_path(PIDGIN_PREFS_ROOT "/browsers/command")) != NULL) {
+		purple_prefs_set_string(PIDGIN_PREFS_ROOT "/browsers/manual_command", str);
+		purple_prefs_remove(PIDGIN_PREFS_ROOT "/browsers/command");
+	}
+
 	/* this string pref moved into the core, try to be friendly */
 	purple_prefs_rename(PIDGIN_PREFS_ROOT "/idle/reporting_method", "/purple/away/idle_reporting");
 	if ((str = purple_prefs_get_string("/purple/away/idle_reporting")) &&
